.. _auxilfuncs:

BASTA auxiliary functions
*************************

Plotting functions
==================

.. automodule:: plot_corner
   :members:

.. automodule:: plot_interp
   :members:

.. automodule:: plot_kiel
   :members:

.. automodule:: plot_seismic
   :members:

Processing tools
================

.. automodule:: create_inputfile
   :members:

.. automodule:: downloader
   :members:

.. automodule:: preview_interpolation
   :members:

.. automodule:: process_jsonfile
   :members:
